
 getwd()
 source("EVA-functions.R")
 library(akima)

# CHOOSE WHICH R TO PLOT FROM R=20 OR R=50 

 R=20


 print(load(paste("PotBoot.R",R,".Rdata",sep="")))
 ws<-unique(means$w)
 Ms<-unique(means$M)
 PIs<-unique(means$PI)
 nw<-length(ws)
 nM<-length(Ms)
 nPI<-length(PIs)


#Note: Method codes	"X"	for XIMIS with known index w	(XMS)
#				"W"	for XIMIS fitting index w	(XMW)
#				"G"	for GPD method 			(GPD)

MRI=10000		# Select mean recurrence interval (MRI)
method<-"G"		# Select method from "X" "W", or "G"


Name<-paste(method,MRI,sep="")
levels<-c(-1,0,1,2,5)
levels<-c(levels/10000,levels/1000,levels/100,levels/10,levels,levels*10,levels*100)
levels<-sort(unique(levels))
pal = col = hcl.colors(100, "YlOrRd", rev = TRUE)

#=========================================================================
#		Bias and variance for each PI
#-------------------------------------------------------------------------
graphics.off()
# mean bias
for (PI in PIs)
{Lim=c(-0.2,0.5)
 Mx<-means[means$PI==PI,]
 V<-Mx[,Name]
 Vtgt<-V
 for (i in c(1:length(V)))
  Vtgt[i]<-qximis(-log(-log(1-1/MRI)),c(PI,1,Mx[i,"w"]))
 V<-V/Vtgt-1
 mx<-interp(Mx$M,Mx$w,V,nx=nM*10,ny=nw*10,linear=TRUE)
 dev.new()
 image(mx,main=bquote(bold("Bias error of"~.(Name)~"for "~italic(Pi)==.(PI))),
       ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)),zlim=Lim,col=pal)
 contour(mx,add=TRUE,labcex=1,lwd=2,levels=levels)
 mtext(bquote(bar(epsilon)(italic(V)[.(MRI)])/~italic(V)[.(MRI)]))
 box(lwd=2)
}

graphics.off()
# variances
for (PI in PIs)
{Lim=c(log(5e-5),log(1))
 Mx<-variances[variances$PI==PI,]
 V<-Mx[,Name]
 Vtgt<-V
 for (i in c(1:length(V)))
  Vtgt[i]<-qximis(-log(-log(1-1/MRI)),c(PI,1,Mx[i,"w"]))
 V<-sqrt(V)/Vtgt
 mx<-interp(Mx$M,Mx$w,V,nx=nM*10,ny=nw*10,linear=TRUE)
 dev.new()
 image(mx$x,mx$y,log(mx$z),
   main=bquote(bold("Standard error of"~.(Name)~"for "~italic(Pi)==.(PI))),
       ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)),zlim=Lim,col=pal)
 contour(mx,add=TRUE,labcex=1,lwd=2,levels=levels)
 box(lwd=2)
 mtext(bquote(bar(sigma)(italic(V)[.(MRI)])/~italic(V)[.(MRI)]))
}


#=========================================================================
#		Bias and variance for each M
#-------------------------------------------------------------------------
graphics.off()
# mean bias
for (m in Ms)
{Lim=c(-0.2,0.5)
 Mx<-means[means$M==m,]
 V<-Mx[,Name]
 Vtgt<-V
 for (i in c(1:length(V)))
  Vtgt[i]<-qximis(-log(-log(1-1/MRI)),c(Mx[i,"PI"],1,Mx[i,"w"]))
 V<-V/Vtgt-1
 mx<-interp(Mx$PI,Mx$w,V,nx=nPI*10,ny=nw*10,linear=TRUE)
 dev.new()
 image(mx,main=bquote(bold("Bias error of"~.(Name)~"for "~italic(M)==.(m)~", "~italic(R)==.(R))),
    ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)),zlim=Lim,col=pal)
 contour(mx,add=TRUE,labcex=1,lwd=2,levels=levels)
 box(lwd=2)
 mtext(bquote(bar(epsilon)(italic(V)[.(MRI)])/~italic(V)[.(MRI)])) 
}

graphics.off()
# variances
for (m in Ms)
{Lim=c(log(5e-5),log(1))
 Mx<-variances[variances$M==m,]
 V<-Mx[,Name]
 Vtgt<-V
 for (i in c(1:length(V)))
  Vtgt[i]<-qximis(-log(-log(1-1/MRI)),c(Mx[i,"PI"],1,Mx[i,"w"]))
 V<-sqrt(V)/Vtgt
 mx<-interp(Mx$PI,Mx$w,V,nx=nPI*10,ny=nw*10,linear=TRUE)
 dev.new()
 image(mx$x,mx$y,log(mx$z),main=bquote(bold("Standard error of"~.(Name)~"for "~italic(M)==.(m)~", "~italic(R)==.(R))),
    ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)),zlim=Lim,col=pal)
 contour(mx,add=TRUE,labcex=1,lwd=2,level=levels)
 box(lwd=2)
 mtext(bquote(bar(sigma)(italic(V)[.(MRI)])/~italic(V)[.(MRI)])) 
}

#=========================================================================
#		GPD shape parameter
#-------------------------------------------------------------------------

graphics.off()
# GPD shape parameter for Weibull index
for (w in ws)
{M<-means[means$w==w,]
 mx<-interp(M$M,M$PI,M$shp,nx=nM*10,ny=nPI*10,linear=TRUE)
 dev.new()
 image(mx,main=bquote(bold("GEV shape parameter "~italic(xi)~" for"~italic(w)==.(w))),
  xlab=bquote("Ranks, "~italic(M)),
   ylab=bquote("Characteristic product, "~italic(Pi)),col=rev(col))
 abline(h=c(1:15),col="grey")
 contour(mx,add=TRUE,labcex=1,lwd=2)
 box(lwd=2)
}

graphics.off()
# GPD shape parameter for number of ranks, M
for (M in Ms)
{Mx<-means[means$M==M,]
 mx<-interp(Mx$PI,Mx$w,Mx$shp,ny=nw*10,nx=nPI*10,linear=TRUE)
 dev.new()
 image(mx,col=col,
   main=bquote(bold("GPD shape parameter "~italic(xi)~" for "~italic(M)==.(M)~", "~italic(R)==.(R))),
       ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)))
 contour(mx,add=TRUE,labcex=1,lwd=2,levels=seq(-1,1,0.02))
 box(lwd=2)
 mtext("Probability-weighted moments fit to GPD")
}



graphics.off()
# XMW index for Weibull index
for (w in ws)
{M<-means[means$w==w,]
 mx<-interp(M$M,M$PI,M$wxmw,nx=nM*10,ny=nPI*10,linear=TRUE)
 dev.new()
 image(mx,main=bquote(bold("XIMIS Index ="~italic(w))),
  xlab=bquote("Ranks, "~italic(M)),ylab=bquote("Characteristic product, "~italic(Pi)))
 contour(mx,add=TRUE,labcex=1,lwd=2)
 box(lwd=2)
 mtext("Weighted LMS fit to penultimate FT1")
}


graphics.off()
# XMW index for number of ranks, M
for (M in Ms)
{Mx<-means[means$M==M,]
 mx<-interp(Mx$PI,Mx$w,Mx$wxmw,ny=nw*10,nx=nPI*10,linear=TRUE)
 dev.new()
 image(mx,main=bquote(bold("XIMIS Index for "~italic(M)==.(M)~","~italic(R)==.(R))),
       ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)))
 contour(mx,add=TRUE,labcex=1,lwd=2)
 box(lwd=2)
 mtext("Weighted LMS fit to penultimate FT1")
}


plot(means$wxmw,means$shp,main="GPD shape ~ XMW index equivalence",
      xlab=expression("XMW index, "~italic(w)),
        ylab=expression("GPD shape, "~italic(xi))),ylim=c(-0.3,0.2))


#=============================================================================================
#			Plot standard error of "W" or "G" as ratio of "X"
#-------------------------------------------------------------------------------------
	pal = col = hcl.colors(100, "YlOrRd", rev = TRUE)

R=20
MRI=10000
M=100
method<-"W"

 print(load(paste("PotBoot.R",R,".Rdata",sep="")))

 ws<-unique(means$w)
 Ms<-unique(means$M)
 PIs<-unique(means$PI)
 nw<-length(ws)
 nM<-length(Ms)
 nPI<-length(PIs)
 XName<-paste("X",MRI,sep="")
 Mx<-variances[variances$M==M,]
 VX<-Mx[,XName]
Name<-paste(method,MRI,sep="")
  V<-Mx[,Name]/VX
  V<-sqrt(V)
 mx<-interp(Mx$PI,Mx$w,V,nx=nPI*10,ny=nw*10,linear=TRUE)
# dev.new()
 image(mx$x,mx$y,log(mx$z),col=pal,
   main=bquote(bold("Standard error ratio"~.(Name)~"/"~.(XName)~" for "~italic(M)==.(M)~", "~italic(R)==.(R))),
       ylab=expression("Weibull index, "~italic(w)),
    xlab=expression("Characteristic product, "~italic(Pi)))
 contour(mx,add=TRUE,labcex=1,lwd=2)
 box(lwd=2)
 mtext(bquote("Mean = "~.(round(mean(V),2))))
 print(paste("Mean ratio =",round(mean(V),2)))


